cesium library

Classes

ActionResource<T>
An observable wrapper around an asynchronous operation that supports cancellation and an optional option to preserve the last successful result while the new operation runs.
ActionResourceValue<T>
Represents the current state of a ActionResource.
Cesium
Top-level helpers for global Cesium configuration and error forwarding.
CesiumHttpService
Simple HTTP service built on top of dio exposed as a CesiumService.
CesiumService
Base class for long-lived services managed by Cesium.
ComputedResource<T>
A ValueNotifier whose value is computed from other Listenable dependencies.
FutureResource<T>
An observable wrapper around an asynchronous operation that supports cancellation and an optional option to preserve the last successful result while the new operation runs.
FutureResourceValue<T>
Represents the current state of a FutureResource.
HttpResource<T>
Simple HTTP-backed resource that fetches a single value of type T.
PaginatedHttpResource<T>
Resource that supports paginated HTTP requests and accumulates results.
ServiceProvider<T extends CesiumService>
Helper to register and optionally override a service factory in a concise, test-friendly way.

Enums

ActionStatus
Enum representing the current status of the action

Mixins

ManagedListenerMixin<T extends StatefulWidget>
Mixin to manage Listenable listeners and automatically remove them when the State is disposed.

Extensions

CesiumListenableListX on List<Listenable>
Helpers for a list of Listenable objects merged into a single Listenable via Listenable.merge.
CesiumListenableX on Listenable
Convenience builders for generic Listenable objects.
CesiumValueNotifierFutureResourceX on ValueNotifier<FutureResourceValue<T>>
Extensions to make it concise to render ValueNotifier<FutureResourceValue<T>> values in the widget tree.
CesiumValueNotifierX on ValueNotifier<T>
Extensions to make it concise to render ValueNotifier values in the widget tree.

Properties

cesiumHttpServiceProvider ServiceProvider<CesiumHttpService>
Global provider for the shared CesiumHttpService.
final

Functions

injectService<T extends CesiumService>() → T
Return the singleton instance of the registered service T.
register<T extends CesiumService>(T factory()) → void
Register a factory for a service type T.
registerOverride<T extends CesiumService>(T factory()) → void
Register an overriding factory for service type T.
resetService<T extends CesiumService>() → void
Reset (or recreate) the registered service instance for type T.
resetServices() → void
Reset all currently created service instances by calling reset() on each one.