Cesium class
Top-level helpers for global Cesium configuration and error forwarding.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
logError(
Object error) → void - Log an error through the configured handler if present.
-
setErrorHandler(
void errorHandler(Object error)) → void -
Set a global error handler that will receive errors logged by the
library (for example from background computations) or the user through
Cesium.logError.