CesiumHttpService class

Simple HTTP service built on top of dio exposed as a CesiumService.

Inheritance
Available extensions

Constructors

CesiumHttpService({Dio dioBuilder()?})
CesiumHttpService constructor, if _dioBuilder is provided, it will be used instead of the default Dio constructor

Properties

baseOptions ↔ BaseOptions
Access or replace the underlying BaseOptions used by dio.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
interceptors → Interceptors
Interceptors applied to the underlying dio client.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
delete(String url, {Object? data, Options? options, Map<String, dynamic>? params, CancelToken? cancelToken}) Future<Response>
Perform an HTTP DELETE request.
dispose() → void
Discards any resources used by the object.
inherited
get(String url, {Object? data, Options? options, Map<String, dynamic>? params, CancelToken? cancelToken, void onReceiveProgress(int, int)?}) Future<Response>
Perform an HTTP GET request.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
patch(String url, {Object? data, Options? options, Map<String, dynamic>? params, CancelToken? cancelToken, void onReceiveProgress(int, int)?, void onSendProgress(int, int)?}) Future<Response>
Perform an HTTP PATCH request.
pipe(Widget builder(BuildContext context)) ListenableBuilder

Available on Listenable, provided by the CesiumListenableX extension

Build a ListenableBuilder for this Listenable.
pipeChild(Widget builder(BuildContext context, Widget? child), {Widget? child}) ListenableBuilder

Available on Listenable, provided by the CesiumListenableX extension

Like pipe but supplies a static child to the builder.
post(String url, {Object? data, Options? options, Map<String, dynamic>? params, CancelToken? cancelToken, void onReceiveProgress(int, int)?, void onSendProgress(int, int)?}) Future<Response>
Perform an HTTP POST request.
put(String url, {Object? data, Options? options, Map<String, dynamic>? params, CancelToken? cancelToken, void onReceiveProgress(int, int)?, void onSendProgress(int, int)?}) Future<Response>
Perform an HTTP PUT request.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reset() → void
Reset the service to its initial state.
override
setDioBuilder(Dio builder()) → void
Sets the builder used to build the dio instance Immediately rebuilds the dio instance
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited